@@ -236,6 +236,21 @@ decompose.ssa <- function(x,
   } else if (identical(x$svd.method, "propack")) {
     S <- propack.svd(.get.or.create.trajmat(x), neig = neig, ...)
     .set.decomposition(x, sigma = S$d, U = S$u, V = S$v)
+  } else if (identical(x$svd.method, "rspectra")) {
+    if (!requireNamespace("RSpectra", quietly = TRUE))
+        stop("RSpectra package is required for SVD method `rspectra'")
+    h <- .get.or.create.trajmat(x)
+    A <- function(x, args) ematmul(args, x)
+    Atrans <- function(x, args) ematmul(args, x, transposed = TRUE)
+    S <- RSpectra::svds(A, k = neig, Atrans = Atrans, dim = dim(h), args = h, ...)
+    .set.decomposition(x, sigma = S$d, U = S$u, V = S$v)
+  } else if (identical(x$svd.method, "primme")) {
+    if (!requireNamespace("PRIMME", quietly = TRUE))
+        stop("PRIMME package is required for SVD method `primme'")
+    h <- .get.or.create.trajmat(x)
+    pA <-function(x, trans) if (identical(trans, "c")) crossprod(h, x) else h %*% x
+    S <- PRIMME::svds(pA, NSvals = neig, m = nrow(h), n = ncol(h), isreal = TRUE, ...)
+    .set.decomposition(x, sigma = S$d, U = S$u, V = S$v)
   } else
     stop("unsupported SVD method")
 
